@@ -1,6 +1,5 @@
 library(track2KBA)
 library(lubridate)
-library(rgdal)
 library(sp)
 
 dat <- data.frame(Longitude = c(1, 2, 3, 1), 
@@ -10,12 +9,16 @@ dat <- data.frame(Longitude = c(1, 2, 3, 1),
                     ymd_hms("2021-01-01 00:00:00") + hours(0:3))
 )
 
-expect_message(projectTracks(dataGroup = dat, projType = "azim", custom = TRUE))
-expect_message(projectTracks(dataGroup = dat, 
+expect_message(
+  projectTracks(dataGroup = dat, projType = "azim", custom = TRUE))
+expect_message(
+  projectTracks(dataGroup = dat, 
                             projType = "cylin", custom = TRUE))
-expect_message(projectTracks(dataGroup = dat, 
+expect_message(
+  projectTracks(dataGroup = dat, 
                              projType = "azim", custom = FALSE))
-expect_message(projectTracks(dataGroup = dat, 
+expect_message(
+  projectTracks(dataGroup = dat, 
                             projType = "cylin", custom = FALSE))
 
 xy <- dat[,c(1,2)]
@@ -25,15 +28,17 @@ dat_spdf <- sp::SpatialPointsDataFrame(
     sp::CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0")
 )
 
-expect_message(projectTracks(dataGroup = dat_spdf,
-                            projType = "azim", custom = TRUE))
+expect_message(
+  projectTracks(dataGroup = dat_spdf, projType = "azim", custom = TRUE))
+expect_message(
+  projectTracks(dataGroup = dat_spdf, projType = "cylin", custom = TRUE))
 
 ## can transform projected SPDF
 dat_prj <- projectTracks(dataGroup = dat, 
               projType = "cylin", custom = FALSE)
 
-expect_message(projectTracks(dataGroup = dat_prj,
-                           projType = "azim", custom = TRUE))
+expect_message(
+  projectTracks(dataGroup = dat_prj, projType = "azim", custom = TRUE))
 
 ## needs Lat Long columns to do so
 dat_prj <- dat_prj[, -(1:2)]
@@ -52,22 +57,5 @@ dat_idl <- data.frame(Longitude = rep(c(-170:-179, 179:170)),
 
 expect_message(
   projectTracks(dataGroup = dat_idl, projType = "azim", custom = TRUE))
-  expect_message(
+expect_message(
   projectTracks(dataGroup = dat_idl, projType = "cylin", custom = TRUE))
-
-
-xy <- dat_idl[,c(1,2)]
-dat_spdf <- sp::SpatialPointsDataFrame(
-  data = dat_idl, coords = xy,
-  proj4string =
-    sp::CRS("+proj=longlat +datum=WGS84 +ellps=WGS84 +towgs84=0,0,0")
-)
-
-expect_message(
-  projectTracks(dataGroup = dat_spdf, projType = "azim", custom = TRUE))
-expect_message(
-  projectTracks(dataGroup = dat_spdf, projType = "cylin", custom = TRUE))
-expect_message(
-  projectTracks(dataGroup = dat_spdf, projType = "azim", custom = TRUE))
-expect_message(
-  projectTracks(dataGroup = dat_spdf, projType = "cylin", custom = TRUE))
